# that-ml-library

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

``` sh
pip install that_ml_library
```

For tree visualization function
([`plot_tree_dtreeviz`](https://anhquan0412.github.io/that-ml-library/chart_plotting.html#plot_tree_dtreeviz)
or
[`plot_tree_sklearn`](https://anhquan0412.github.io/that-ml-library/chart_plotting.html#plot_tree_sklearn)),
you also need to install `graphviz`. Please follow the instruction
[here](https://github.com/parrt/dtreeviz#installation)

## How to use

Please visit <https://anhquan0412.github.io/that-ml-library/> for
tutorials and documentations

## A word of caution

This library should only be utilized solely for developing a proof of
concept or prototype for your machine learning model with your specific
dataset, with the aim of evaluating the model’s performance and
interpretability. For deployment in a production environment, opt for a
more organized methodology, such as
<https://scikit-learn.org/stable/modules/compose.html#pipeline>
